==> 0.0.3.tar.gz: lib/package/button.dart <==
import 'package:flutter/material.dart';

class MillButton extends StatelessWidget {
  MillButton({
    this.key,
    this.onPressed,
    this.child,
    this.type = 'primary',
    this.textColor,
    this.color,
    this.highlightColor,
    this.disabledColor,
    this.disabledTextColor,
    this.disabledBorderColor,
    this.borderColor,
    this.plain = false,
    this.radius = 5,
    this.height = 36,
    this.disabled = false,
    this.gradient,
  }) : super(key: key);
  final Key key;
  final Function onPressed;
  final String type;
  final Color textColor;
  final Color color;
  final Color highlightColor;
  final Color disabledTextColor;
  final Color disabledBorderColor;
  final Color borderColor;
  final Color disabledColor;
  final bool plain;
  final double radius;
  final Widget child;
  final Gradient gradient;
  final double height;
  final bool disabled;

  @override
  Widget build(BuildContext context) {
    if (gradient != null) {
      return FlatButton(
        textColor: getColor(textColor, themes[type]['textColor']),
        shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(46)),
        onPressed: disabled || onPressed == null ? null : onPressed,
        padding: EdgeInsets.all(0),
        highlightColor: getColor(color, themes[type]['highlightColor']),
        child: Container(
            height: height,
            alignment: Alignment.center,
            decoration: BoxDecoration(
                color: getColor(color, themes[type]['color']),
                gradient: gradient, // 渐变色
                borderRadius: BorderRadius.circular(radius)),
            child: child),
      );
    }
    if (plain) {
      return OutlineButton(
        disabledBorderColor: getColor(
            disabledBorderColor, linethemes[type]['disabledBorderColor']),
        disabledTextColor:
            getColor(disabledTextColor, linethemes[type]['disabledTextColor']),
        highlightedBorderColor:
            getColor(color, linethemes[type]['borderColor']),
        borderSide: BorderSide(
            width: 1,
            color: getColor(borderColor, linethemes[type]['borderColor'])),
        textColor: getColor(textColor, linethemes[type]['textColor']),
        shape:
            RoundedRectangleBorder(borderRadius: BorderRadius.circular(radius)),
        onPressed: disabled || onPressed == null ? null : onPressed,
        child: child,
      );
    } else {
      return RaisedButton(
        disabledColor: getColor(disabledColor, themes[type]['disabledColor']),
        disabledTextColor: getColor(textColor, themes[type]['textColor']),
        color: getColor(color, themes[type]['color']),
        highlightColor:
            getColor(highlightColor, themes[type]['highlightColor']),
        textColor: getColor(textColor, themes[type]['textColor']),
        shape:
            RoundedRectangleBorder(borderRadius: BorderRadius.circular(radius)),
        onPressed: disabled || onPressed == null ? null : onPressed,
        child: child,
      );
    }
  }
}

Map themes = {
  'primary': {
    'textColor': Color(0xffffffff),
    'color': Color(0xff409eff),
    'borderColor': Color(0xff409eff),
    'highlightColor': Color(0xff3898FB),
    'disabledColor': Color(0xffa0cfff),
  },
  'error': {
    'textColor': Color(0xffffffff),
    'color': Color(0xfff56c6c),
    'borderColor': Color(0xfff56c6c),
    'highlightColor': Color(0xffF45C5C),
    'disabledColor': Color(0xfffab6b6),
  },
  'warning': {
    'textColor': Color(0xffffffff),
    'color': Color(0xffe6a23c),
    'borderColor': Color(0xffe6a23c),
    'highlightColor': Color(0xffDE8B10),
    'disabledColor': Color(0xffefc588),
  },
  'cancel': {
    'textColor': Color(0xff666666),
    'color': Color(0xfff6f7f8),
    'borderColor': Color(0xfff6f7f8),
    'highlightColor': Color(0xffffffff),
    'disabledColor': Color(0xff3f3f4),
  }
};

Map linethemes = {
  'primary': {
    'textColor': Color(0xff409eff),
    'color': Color(0xff409eff),
    'borderColor': Color(0xff409eff),
    'highlightColor': Color(0xffecf5ff),
    'disabledBorderColor': Color(0xffd9ecff),
    'disabledTextColor': Color(0xff8cc5ff),
  },
  'error': {
    'textColor': Color(0xfff56c6c),
    'color': Color(0xfff56c6c),
    'borderColor': Color(0xfff56c6c),
    'highlightColor': Color(0xfffde2e2),
    'disabledBorderColor': Color(0xfffde2e2),
    'disabledTextColor': Color(0xfff9a7a7),
  },
  'warning': {
    'textColor': Color(0xffe6a23c),
    'color': Color(0xffe6a23c),
    'borderColor': Color(0xffe6a23c),
    'highlightColor': Color(0xfffdf6ec),
    'disabledBorderColor': Color(0xfff8e8cf),
    'disabledTextColor': Color(0xffebb970),
  },
  'cancel': {
    'textColor': Color(0xff666666),
    'color': Color(0xfff6f6f6),
    'borderColor': Color(0xffd4d5d6),
    'highlightColor': Color(0xffffffff),
    'disabledColor': Color(0xff3f3f4),
  }
};

getColor(color, defaultColor) {
  return color == null ? defaultColor : color;
}

==> 0.0.4.tar.gz: lib/package/button.dart <==
import 'package:flutter/material.dart';

class MillButton extends StatelessWidget {
  MillButton({
    this.key,
    this.onPressed,
    this.child,
    this.type = 'primary',
    this.textColor,
    this.color,
    this.highlightColor,
    this.disabledColor,
    this.disabledTextColor,
    this.disabledBorderColor,
    this.borderColor,
    this.plain = false,
    this.radius = 5,
    this.height = 36,
    this.disabled = false,
    this.gradient,
  }) : super(key: key);
  final Key key;
  final Function onPressed;
  final String type;
  final Color textColor;
  final Color color;
  final Color highlightColor;
  final Color disabledTextColor;
  final Color disabledBorderColor;
  final Color borderColor;
  final Color disabledColor;
  final bool plain;
  final double radius;
  final Widget child;
  final Gradient gradient;
  final double height;
  final bool disabled;

  @override
  Widget build(BuildContext context) {
    if (gradient != null) {
      return Ink(
        decoration: BoxDecoration(
          gradient: gradient,
          borderRadius: BorderRadius.circular(radius),
          boxShadow: [
            BoxShadow(
                color: Colors.black12,
                offset: Offset(0.0, 15.0), //阴影xy轴偏移量
                blurRadius: 15.0, //阴影模糊程度
                spreadRadius: 1.0 //阴影扩散程度
            ),
          ],
        ),
        child: InkWell(
          borderRadius: BorderRadius.circular(radius),
          onTap: disabled || onPressed == null ? null : onPressed,
          child: Container(
            alignment: Alignment.center,
            height: height,
            child: child,
          ),
        ),
      );
    }
    if (plain) {
      return OutlineButton(
        disabledBorderColor: getColor(
            disabledBorderColor, linethemes[type]['disabledBorderColor']),
        disabledTextColor:
            getColor(disabledTextColor, linethemes[type]['disabledTextColor']),
        highlightedBorderColor:
            getColor(color, linethemes[type]['borderColor']),
        borderSide: BorderSide(
            width: 1,
            color: getColor(borderColor, linethemes[type]['borderColor'])),
        textColor: getColor(textColor, linethemes[type]['textColor']),
        shape:
            RoundedRectangleBorder(borderRadius: BorderRadius.circular(radius)),
        onPressed: disabled || onPressed == null ? null : onPressed,
        child: child,
      );
    } else {
      return RaisedButton(
        disabledColor: getColor(disabledColor, themes[type]['disabledColor']),
        disabledTextColor: getColor(textColor, themes[type]['textColor']),
        color: getColor(color, themes[type]['color']),
        highlightColor:
            getColor(highlightColor, themes[type]['highlightColor']),
        textColor: getColor(textColor, themes[type]['textColor']),
        shape:
            RoundedRectangleBorder(borderRadius: BorderRadius.circular(radius)),
        onPressed: disabled || onPressed == null ? null : onPressed,
        child: child,
      );
    }
  }
}

Map themes = {
  'primary': {
    'textColor': Color(0xffffffff),
    'color': Color(0xff409eff),
    'borderColor': Color(0xff409eff),
    'highlightColor': Color(0xff3898FB),
    'disabledColor': Color(0xffa0cfff),
  },
  'error': {
    'textColor': Color(0xffffffff),
    'color': Color(0xfff56c6c),
    'borderColor': Color(0xfff56c6c),
    'highlightColor': Color(0xffF45C5C),
    'disabledColor': Color(0xfffab6b6),
  },
  'warning': {
    'textColor': Color(0xffffffff),
    'color': Color(0xffe6a23c),
    'borderColor': Color(0xffe6a23c),
    'highlightColor': Color(0xffDE8B10),
    'disabledColor': Color(0xffefc588),
  },
  'cancel': {
    'textColor': Color(0xff666666),
    'color': Color(0xfff6f7f8),
    'borderColor': Color(0xfff6f7f8),
    'highlightColor': Color(0xffffffff),
    'disabledColor': Color(0xff3f3f4),
  }
};

Map linethemes = {
  'primary': {
    'textColor': Color(0xff409eff),
    'color': Color(0xff409eff),
    'borderColor': Color(0xff409eff),
    'highlightColor': Color(0xffecf5ff),
    'disabledBorderColor': Color(0xffd9ecff),
    'disabledTextColor': Color(0xff8cc5ff),
  },
  'error': {
    'textColor': Color(0xfff56c6c),
    'color': Color(0xfff56c6c),
    'borderColor': Color(0xfff56c6c),
    'highlightColor': Color(0xfffde2e2),
    'disabledBorderColor': Color(0xfffde2e2),
    'disabledTextColor': Color(0xfff9a7a7),
  },
  'warning': {
    'textColor': Color(0xffe6a23c),
    'color': Color(0xffe6a23c),
    'borderColor': Color(0xffe6a23c),
    'highlightColor': Color(0xfffdf6ec),
    'disabledBorderColor': Color(0xfff8e8cf),
    'disabledTextColor': Color(0xffebb970),
  },
  'cancel': {
    'textColor': Color(0xff666666),
    'color': Color(0xfff6f6f6),
    'borderColor': Color(0xffd4d5d6),
    'highlightColor': Color(0xffffffff),
    'disabledColor': Color(0xff3f3f4),
  }
};

getColor(color, defaultColor) {
  return color == null ? defaultColor : color;
}
